"""poetry-dotenv - is the plugin that automatically loads environment variables from a dotenv file into the environment before poetry commands are run."""

__title__ = "poetry-dotenv"
__summary__ = "poetry-dotenv - is the plugin that automatically loads environment variables from a dotenv file into the environment before poetry commands are run."
__uri__ = "https://github.com/volopivoshenko/poetry-dotenv"

__version__ = "0.2.2"

__author__ = "Volodymyr Pivoshenko"
__email__ = "volodymyr.pivoshenko@gmail.com"

__license__ = "MIT"
__copyright__ = "Copyright 2022, Volodymyr Pivoshenko"

from poetry_dotenv import dotenv
from poetry_dotenv import plugin
